@@ -1,5 +1,5 @@
 # Import tableone objects
-from .tableone import TableOne
+from .tableone import TableOne, load_dataset
 
 __author__ = "Tom Pollard <tpollard@mit.edu>, Alistair Johnson, Jesse Raffa"
-__version__ = "0.7.3"
\ No newline at end of file
+__version__ = "0.7.4"
\ No newline at end of file
